/****************************************************************************
** Meta object code from reading C++ file 'ksanewidget_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksane-26.04.3/src/ksanewidget_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksanewidget_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto KSaneIface::KSaneWidgetPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSaneIface::KSaneWidgetPrivate",
        "startFinalScan",
        "",
        "startPreviewScan",
        "previewScanDone",
        "KSaneCore::Interface::ScanStatus",
        "status",
        "strStatus",
        "oneFinalScanDone",
        "updateProgress",
        "progress",
        "updatePreviewProgress",
        "updateCountDown",
        "remainingSeconds",
        "handleSelection",
        "tl_x",
        "tl_y",
        "br_x",
        "br_y",
        "signalDevListUpdate",
        "QList<KSaneCore::DeviceInformation*>",
        "deviceList",
        "setTLX",
        "QVariant",
        "x",
        "setTLY",
        "y",
        "setBRX",
        "setBRY",
        "checkInvert",
        "invertPreview",
        "updateScanSelection",
        "setPossibleScanSizes",
        "setPageSize",
        "index",
        "updateCommonGamma",
        "updatePreviewViewer"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'startFinalScan'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startPreviewScan'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previewScanDone'
        QtMocHelpers::SlotData<void(KSaneCore::Interface::ScanStatus, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'oneFinalScanDone'
        QtMocHelpers::SlotData<void(KSaneCore::Interface::ScanStatus, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'updateProgress'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'updatePreviewProgress'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'updateCountDown'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'handleSelection'
        QtMocHelpers::SlotData<void(float, float, float, float)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 15 }, { QMetaType::Float, 16 }, { QMetaType::Float, 17 }, { QMetaType::Float, 18 },
        }}),
        // Slot 'signalDevListUpdate'
        QtMocHelpers::SlotData<void(const QList<KSaneCore::DeviceInformation*> &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setTLX'
        QtMocHelpers::SlotData<void(const QVariant &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setTLY'
        QtMocHelpers::SlotData<void(const QVariant &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 26 },
        }}),
        // Slot 'setBRX'
        QtMocHelpers::SlotData<void(const QVariant &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setBRY'
        QtMocHelpers::SlotData<void(const QVariant &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 26 },
        }}),
        // Slot 'checkInvert'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'invertPreview'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateScanSelection'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setPossibleScanSizes'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setPageSize'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'updateCommonGamma'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePreviewViewer'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KSaneWidgetPrivate, qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSaneIface::KSaneWidgetPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>.metaTypes,
    nullptr
} };

void KSaneIface::KSaneWidgetPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSaneWidgetPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startFinalScan(); break;
        case 1: _t->startPreviewScan(); break;
        case 2: _t->previewScanDone((*reinterpret_cast<std::add_pointer_t<KSaneCore::Interface::ScanStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->oneFinalScanDone((*reinterpret_cast<std::add_pointer_t<KSaneCore::Interface::ScanStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->updateProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->updatePreviewProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->updateCountDown((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->handleSelection((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4]))); break;
        case 8: _t->signalDevListUpdate((*reinterpret_cast<std::add_pointer_t<QList<KSaneCore::DeviceInformation*>>>(_a[1]))); break;
        case 9: _t->setTLX((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 10: _t->setTLY((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 11: _t->setBRX((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 12: _t->setBRY((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 13: _t->checkInvert(); break;
        case 14: _t->invertPreview(); break;
        case 15: _t->updateScanSelection(); break;
        case 16: _t->setPossibleScanSizes(); break;
        case 17: _t->setPageSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->updateCommonGamma(); break;
        case 19: _t->updatePreviewViewer(); break;
        default: ;
        }
    }
}

const QMetaObject *KSaneIface::KSaneWidgetPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSaneIface::KSaneWidgetPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface18KSaneWidgetPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSaneIface::KSaneWidgetPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
